# image pdf tools
Image to pdf and pdf merged python tools

# Setup local
```sh
pip install image-pdf-tools
```

# How to use
```sh
from image_pdf_tools import image_to_pdf, pdf_merge

image_to_pdf('image_path_file.png', 'folder_to_save_image')

image_to_pdf(
    	['pdf_path_file1.pdf', 'pdf_path_file2.pdf'], 
    		
    		'folder_to_save_image')

```

# Features

1. Converter image to pdf
2. Merger many pdf file to one

# Credit
Harouna Diallo